@@ -1,23 +1,10 @@
 /*
   This file is part of the KDE Kontact Plugin Interface Library.
 
-  Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
-  Copyright (c) 2002-2003 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
+  SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 #ifndef KONTACTINTERFACE_CORE_H
@@ -26,11 +13,10 @@
 #include "kontactinterface_export.h"
 
 #include <KParts/MainWindow>
-#include <KParts/ReadOnlyPart>
+#include <KParts/Part>
 
 namespace KontactInterface
 {
-
 class Plugin;
 
 /**
@@ -75,14 +61,14 @@ public:
      * @param library the library to create part from
      * Creates a part from the given @p library.
      */
-    Q_REQUIRED_RESULT KParts::ReadOnlyPart *createPart(const char *library);
+    Q_REQUIRED_RESULT KParts::Part *createPart(const char *library);
 
     /**
      * @internal (for Plugin)
      *
      * Tells the kontact core that a part has been loaded.
      */
-    virtual void partLoaded(Plugin *plugin, KParts::ReadOnlyPart *part) = 0;
+    virtual void partLoaded(Plugin *plugin, KParts::Part *part) = 0;
 
 Q_SIGNALS:
     /**
@@ -117,4 +103,3 @@ private:
 }
 
 #endif
-
